@@ -10,10 +10,7 @@ class IDrone(IRobot, abc.ABC):
     """
     def __init__(self):
         print('Start IDrone')
-        super(IDrone).__init__()
-
-        self.basic_time_step = int(self.getBasicTimeStep())
-        self.name = self.getName()
+        super().__init__()
         self._set_constants()
         self._set_variables()
 
