@@ -8,10 +8,10 @@ class IRobot(Robot, abc.ABC):
     """
     def __init__(self):
         print('Start IRobot')
-        super().__init__()
+        super(IRobot, self).__init__()
 
     @abc.abstractmethod
-    def initialize(self):
+    def _initialize(self):
         """
         The actions needed to initialize a drone
         :return:
