@@ -9,7 +9,7 @@ class KeyboardControlledDrone(IDrone, abc.ABC):
     """
     def __init__(self):
         print('Start KeyboardDrone')
-        super(KeyboardControlledDrone).__init__()
+        super().__init__()
 
 
     @classmethod
