@@ -11,10 +11,12 @@ from controller import InertialUnit, Camera, LED, Emitter, Receiver, GPS, Compas
 class KeyboardMavic2DJI(KeyboardControlledDrone):
     def __init__(self):
         print('Start KeyboardMavic')
-        super(KeyboardMavic2DJI).__init__()
-        self.initialize()
+        super().__init__()
+        self._initialize()
 
-    def initialize(self):
+    def _initialize(self):
+        self.name = self.getName()
+        self.basic_time_step = int(self.getBasicTimeStep())
         self._attach_and_enable_devices()
         self._attach_and_enable_motors()
         self.keyboard.enable(self.basic_time_step)
@@ -28,10 +30,10 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
         self.emitter: Emitter = self.getEmitter("emitter")
 
         self.receiver: Receiver = self.getReceiver("receiver")
-        self.receiver.enable(self.receiver_time_step)
+        self.receiver.enable(self.basic_time_step)
 
         self.camera: Camera = self.getCamera("camera")
-        self.camera.enable(self.camera_time_step)
+        self.camera.enable(self.basic_time_step)
 
         self.front_left_led: LED = self.getLED("front left led")
         self.front_right_led: LED = self.getLED("front right led")
@@ -137,9 +139,9 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             # self.save_image_every_sec(time, 2)
 
             # Send messages
-            self.send_message(StringGenerator.get_random_message(4))
+            self.send_msg(StringGenerator.get_random_message(4))
             # Receive messages
-            self.receive_messages()
+            self.receive_msgs()
 
 
 
